# -*- coding: utf-8 -*-

BASE_DIR = '/odoo_ar/'
IN_CONFIG = '/opt/odoo/etc/'
IN_DATA = '/opt/odoo/data'
IN_LOG = '/var/log/odoo'
IN_CUSTOM_ADDONS = '/opt/odoo/custom-addons'
IN_EXTRA_ADDONS = '/opt/odoo/extra-addons'
IN_DIST_PACKAGES = '/usr/lib/python{}/dist-packages'
IN_DIST_LOCAL_PACKAGES = '/usr/local/lib/python{}/dist-packages'
IN_BACKUP_DIR = '/var/odoo/backups/'